@@ -1,3 +1,7 @@
+"""
+Linear Programming Library.
+"""
+
 import pulp
 import pydecode.hyper as ph
 from collections import defaultdict
@@ -98,14 +102,14 @@ class HypergraphLP:
 
         constraints : :py:class:`Constraints`
         """
-        for constraint in constraints:
+        for i, constraint in enumerate(constraints):
             self.lp += 0 == \
-                constraint.constant + \
+                constraints.bias[i][1] + \
                 sum([coeff * self.edge_vars[edge.id]
                      for (coeff, edge) in constraint])
 
     @staticmethod
-    def make_lp(hypergraph, weights, name="", integral=False):
+    def make_lp(hypergraph, potentials, name="", integral=False):
         r"""
         Construct a linear program from a hypergraph.
 
@@ -119,7 +123,7 @@ class HypergraphLP:
         ----------
 
         hypergraph : :py:class:`pydecode.hyper.Hypergraph`
-        weights : :py:class:`pydecode.hyper.Weights`
+        potentials : :py:class:`pydecode.hyper.Potentials`
 
         Returns
         --------
@@ -156,7 +160,7 @@ class HypergraphLP:
                 in_edges[node.id].append(edge)
 
         # max \theta x
-        prob += sum([weights[edge] * edge_vars[edge.id]
+        prob += sum([potentials[edge] * edge_vars[edge.id]
                      for edge in hypergraph.edges])
 
         # x(r) = 1
