@@ -10,7 +10,7 @@
 #include <vector>
 
 #include "./common.h"
-#include "Hypergraph/Semirings.h"
+
 using namespace std;
 
 class Hypernode;
@@ -27,42 +27,44 @@ struct HypergraphException : public exception {
   const char* what() const throw() { return s.c_str(); }
 };
 
-class HypergraphAccessException : public HypergraphException {
-};
+class HypergraphAccessException : public HypergraphException {};
+class HypergraphMatchException : public HypergraphException {};
+class HypergraphConstructionException : public HypergraphException {};
 
-class HypergraphMatchException : public HypergraphException {
-
-};
-
-class HypergraphConstructionException : public HypergraphException {
-
-};
-
-// Base class for weighted hyperedge.
 class Hyperedge {
  public:
-  Hyperedge(string label,
-            HNode head,
+  Hyperedge(string label, HNode head,
             const vector<HNode> &tails)
     : id_(-1),
       label_(label),
       head_(head),
       tail_nodes_(tails) {}
 
-  // Get the id of the edge.
+  /**
+   * Get the id of the edge.
+   */
   int id() const { return id_; }
 
   void set_id(int id) { id_ = id; }
 
-  // Get the label of the edge.
+  /**
+   * Get the label of the edge.
+   */
   string label() const { return label_; }
 
-  // Get the head node of the edge.
+  /**
+   * Get the head node of the edge.
+   */
   HNode head_node() const { return head_; }
 
-  // Get the tail nodes of the hyperedge in order.
+  /**
+   * Get the tail nodes of the hyperedge in order.
+   */
   const vector<HNode> &tail_nodes() const { return tail_nodes_; }
 
+  /**
+   * Topological order on edges.
+   */
   bool operator<(const Hyperedge *edge2) const {
     return id() < edge2->id();
   }
@@ -94,9 +96,14 @@ class Hypernode {
     edges_.push_back(edge);
   }
 
-  // Get all hyperedges with this hypernode as head.
+  /**
+   * Get all hyperedges with this hypernode as head.
+   */
   const vector<HEdge> &edges() const { return edges_; }
 
+  /**
+   * Is the node a terminal node.
+   */
   bool terminal() const { return edges_.size() == 0; }
 
  private:
@@ -119,9 +126,9 @@ class Hypergraph {
    */
   HNode root() const { return root_; }
 
-  // Switching to iterator interface
+
   /**
-   * Get all hypernodes in the hypergraph. (Assume unordered)
+   * Get all hypernodes in the hypergraph. Ordered topologically.
    * WARNING: Treat this as a const iterator.
    * @return Const iterator to hypernodes in hypergraph.
    */
@@ -130,7 +137,7 @@ class Hypergraph {
   }
 
   /**
-   * Get all hyperedges in the hypergraph. (Assume unordered)
+   * Get all hyperedges in the hypergraph. Ordered topologically.
    * WARNING: Treat this as a const iterator.
    * @return Const iterator to edges in hypergraph .
    */
@@ -140,31 +147,47 @@ class Hypergraph {
 
   // Construction Code.
 
-  // Create a new node and begin adding edges.
+  /**
+   * Create a new node and begin adding edges.
+   */
   HNode add_terminal_node(string label);
 
   HNode start_node(string label);
 
   HEdge add_edge(const vector<HNode> &nodes, string label);
 
-  // Returns true if the node was created.
-  // Returns false if the node was removed (no children).
+  /**
+   * Returns true if the node was created.
+   * Returns false if the node was removed (no children).
+   */
   bool end_node();
 
-  // Complete the hypergraph.
+  /**
+   * Complete the hypergraph.
+   */
   void finish() {
     if (temp_nodes_.size() == 0) {
       throw HypergraphException("Hypergraph has size 0.");
     }
     root_ = temp_nodes_[temp_nodes_.size() - 1];
     fill();
+    if (nodes_.size() == 0) {
+      throw HypergraphException("Final hypergraph has node size 0.");
+    }
+    if (edges_.size() == 0) {
+      throw HypergraphException("Final hypergraph has edge size 0.");
+    }
     // TODO(srush) Run checks to make sure we are complete.
   }
 
-  // Remove paths that do not reach the root.
+  /**
+   * Remove paths that do not reach the root.
+   */
   void fill();
 
-
+  /**
+   * Is this hypergraph the same as other.
+   */
   bool same(const Hypergraph &other) const { return other.id_ == id_; }
 
  private:
@@ -205,125 +228,56 @@ class Hyperpath {
   Hyperpath(const Hypergraph *graph,
             const vector<HEdge> &edges)
       : graph_(graph), edges_(edges) {
+    HEdge last_edge = NULL;
     foreach (HEdge edge, edges) {
       edges_set_.insert(edge->id());
+      if (last_edge != NULL && last_edge->id() >= edge->id()) {
+        throw HypergraphException("Hyperpath is not in order.");
+      }
+      last_edge = edge;
     }
   }
 
+  /**
+   * Get the edges in the path. In topological order.
+   */
   const vector<HEdge> &edges() const {
     return edges_;
   }
 
+  /**
+   * Is edge in the hyperpath.
+   */
   bool has_edge(HEdge edge) const {
-    return edges_set_.find(edge->id())
-        != edges_set_.end();
+    return edges_set_.find(edge->id()) != edges_set_.end();
   }
 
+
+  /**
+   * Is this hyperpath associated with the hypergraph.
+   */
   void check(const Hypergraph &graph) const {
     if (!graph.same(*graph_)) {
       throw HypergraphException("Hypergraph does not match path.");
     }
   }
 
+  bool equal(const Hyperpath &path) const {
+    check(*path.graph_);
+    if (edges_.size() != path.edges_.size()) return false;
+    for (int i = 0; i < edges_.size(); ++i) {
+      if (edges_[i]->id() != path.edges_[i]->id()) {
+        return false;
+      }
+    }
+    return true;
+  }
+
  private:
   const Hypergraph *graph_;
   set<int> edges_set_;
   const vector<HEdge> edges_;
-
 };
 
-class HypergraphProjection;
-
-template<typename SemiringType = double>
-class HypergraphWeights {
- public:
-  HypergraphWeights(const Hypergraph *hypergraph,
-                    const vector<SemiringType> &weights,
-                    SemiringType bias)
-  : hypergraph_(hypergraph),
-    weights_(weights),
-    bias_(bias) {
-      assert(weights.size() == hypergraph->edges().size());
-  }
-
-  SemiringType dot(const Hyperpath &path) const;
-
-  SemiringType score(HEdge edge) const { return weights_[edge->id()]; }
-
-  SemiringType bias() const { return bias_; }
-
-  HypergraphWeights<SemiringType> *modify(const vector<SemiringType> &, SemiringType) const;
-  
-  HypergraphWeights<SemiringType> *project_weights(
-      const HypergraphProjection &projection) const;
-
-  void check(const Hypergraph &graph) const {
-    if (!graph.same(*hypergraph_)) {
-      throw HypergraphException("Hypergraph does not match weights.");
-    }
-  }
-
- private:
-  const Hypergraph *hypergraph_;
-  vector<SemiringType> weights_;
-  SemiringType bias_;
-};
-
-class HypergraphProjection {
- public:
-  HypergraphProjection(const Hypergraph *original,
-                       const Hypergraph *_new_graph,
-                       const vector<HNode> *node_map,
-                       const vector<HEdge> *edge_map)
-      : original_graph(original),
-      new_graph(_new_graph),
-      node_map_(node_map),
-      edge_map_(edge_map) {
-        assert(node_map->size() == original_graph->nodes().size());
-        assert(edge_map->size() == original_graph->edges().size());
-        foreach (HNode node, *node_map) {
-          assert(node == NULL ||
-                 node->id() < (int)_new_graph->nodes().size());
-        }
-        foreach (HEdge edge, *edge_map) {
-          assert(edge == NULL ||
-                 edge->id() < (int)_new_graph->edges().size());
-        }
-      }
-
-  ~HypergraphProjection() {
-    delete node_map_;
-    delete edge_map_;
-  }
-
-  static HypergraphProjection *project_hypergraph(
-      const Hypergraph *hypergraph,
-      vector<bool> edge_mask);
-
-  HEdge project(HEdge original) const {
-    return (*edge_map_)[original->id()];
-  }
-
-  HNode project(HNode original) const {
-    return (*node_map_)[original->id()];
-  }
-
-  const Hypergraph *original_graph;
-  const Hypergraph *new_graph;
-
- private:
-
-  // Owned.
-  const vector<HNode> *node_map_;
-  const vector<HEdge> *edge_map_;
-};
-
-
-// Given an original hypergraph, builds a pruned hypergraph with only
-// edges in the mask.
-Hypergraph *build_pruned_hypergraph(
-    const Hypergraph *hypergraph,
-    vector<bool> edge_mask,
-    vector<HEdge *> edge_map);
 
 #endif  // HYPERGRAPH_HYPERGRAPH_H_
